!
!   exposures:  Loop over all instruments, data modes, exposures and
!               print for each tuple: main data set, and associated
!               auxiliary/counting-cycle/periodic-HK set (if exists)
!               see also cxxtest/exposures.cc
!
!   AUTHOR:
!       UL, Wed May 31 13:53:12 MET DST 2000
!
!   $Header: /home/sasbuild/repositories/sasdev/sas/packages/oal/f90test/exposures.f90,v 1.5 2003/06/16 08:41:35 gvacanti Exp $
!
program exposures

use oal
use caloaldefs
use errorhandling

    implicit none
    integer                 :: instr, dataMode, nExps, exp, dum
    character(len=256)      :: setName


    do instr=EMOS1, OM
        if (instr == ERM) cycle         !  not interested in ERM stuff

        call OAL_setState(instr)
        do dataMode = IMAGING, NON_PERIODIC_HOUSEKEEPING
            nExps = OAL_selectScope(instr, dataMode)
            if (nExps == 0) cycle       !  no exposures

            write(*, *) 'Exposures of ', instId(instr), ' in data mode: ', &
                        trim(dataModeId(dataMode)), ": ", nExps

            do exp = 1, nExps
                write(*, *) 'Exposure ', exp, ':'
                dum = OAL_selectExposure(exp)
                setName = OAL_selectSet(0)
                write(*, *) '  First set               : ', trim(setName)
                !
                !   is there a set for CCD 1
                !
                if (OAL_hasSet(1)) then
                   write(*, *) 'Have set for CCD 1        : ', OAL_selectSet(1)
                else
                   write(*, *) 'No set for CCD 1'
                endif

                !
                !   check filter
                !
                if (OAL_hasIPPV('FILTER')) then
                    write(*, *) ' FILTER: ', OAL_getIPPVstring('FILTER')
                else
                    write(*, *) ' FILTER: *unknown*'
                endif

                !
                !   check if there is an AUXILIARY set
                !
                if (OAL_hasAssociatedSet(AUXILIARY)) then
                    setName = OAL_selectAssociatedSet(AUXILIARY)
                    write(*, *) '  Associated auxiliary set: ', trim(setName)
                else
                    write(*, *) '  Associated auxiliary set: *none*'
                endif

                !
                !   check if there is a COUNTING_CYCLE_REPORT set
                !
                if (OAL_hasAssociatedSet(COUNTING_CYCLE_REPORT)) then
                    setName = OAL_selectAssociatedSet(COUNTING_CYCLE_REPORT)
                    write(*, *) '  Associated CCX set      : ', trim(setName)
                else
                    write(*, *) '  Associated CXX set      : *none*'
                endif

                !
                !   check if there is a PERIODIC_HOUSEKEEPING set
                if (OAL_hasAssociatedSet(PERIODIC_HOUSEKEEPING)) then
                    setName = OAL_selectAssociatedSet(PERIODIC_HOUSEKEEPING)
                    write(*, *) '  Associated periodic HK  : ', trim(setName)
                else
                    write(*, *) '  Associated periodic HK  : *none*'
                endif
            enddo
        enddo
    enddo

end program
