!
!   odffiles.f90 --- test ODF file name expansion feature
!
!   DESCRIPTION:
!       This program tests the correctness of the OAL file name expansion
!       feature.
!
!   AUTHOR:
!       UL, Wed Dec 17 16:53:31 MET 1997
!
!   $Header: /home/sasbuild/repositories/sasdev/sas/packages/oal/f90test/odffiles.f90,v 1.8 2003/06/16 08:41:35 gvacanti Exp $
!
program oaltest

use oal             ! use the ODF Access Layer
use errorhandling

    implicit none
    character(len=*), parameter         :: odfDir = '../odf'
    character(len=256)                  :: outFileName

    !
    !   open the ODF in directory odfDir and obtain infos
    !
    call OAL_openOdf(odfDir)   ! open the ODF in directory './odf'

    outFileName = OAL_expandSetName('odf(EMOS1, ImAg, 1, 1)')

    call basename(outFileName)
    if (outFileName /= '0010_PPPPPPOOLL_M1S00110IME.FIT') &
        call fatal('odffiles', 'EMOS1 science file name incorrect.')

    !
    !   try to locate the time correlation file
    !
    outFileName = OAL_expandSetName('odf(XMM, TimeCorrelation)')
    call basename(outFileName)
    if (outFileName /= '0010_PPPPPPOOLL_SCX00000TCS.FIT') &
        call fatal('odffiles', 'Time Correlation File name incorrect')

    !
    !   try to locate attitude history file
    !
    outFileName = OAL_expandSetName('odf(XMM, Attitude)')
    call basename(outFileName)
    if (outFileName /= '0010_PPPPPPOOLL_SCX00000ATS.FIT') &
        call fatal('odffiles', 'Attitude History File name incorrect')

end program



subroutine basename(fullName)
    character(*)      :: fullName
    integer           :: in

    in = index(fullName, '/', .true.)
    if (in .lt. len(fullName)) then
        fullName = trim(fullName(in+1:len(fullName)-1))
    endif

end subroutine

