//
//	auxhkgen_emos.cc: create EMOS1 auxiliary + periodic HK file
//
//	Create a simple auxiliary file with frame counters and OBT tags
//	for EMOS1 - also create a simple version of EMOS1 periodic HK file
//	with the EPIC clock reset time at the start	of the exposure #1 in
//	specified in the summary file.
//
//	This is to test the Tags classes.
//

#include "common.h"
#include "Dal.h"
#include "STime.h"
#include "CalOalUtility.h"

using namespace CalOalUtility;

STime start("1999-08-28T08:05:00");

#define NUM_OF(a)	(sizeof(a)/sizeof(a[0]))
int main()
{
	int16 coarset[] = { 0, 32766, 32767, 0, 1, 1, 1, 2, 2, 3, 3 },
//	int16 coarset[] = { 0, 32766, 32767, -32768,  -32767, -32767, -32767,
//						-32766, -32766, -32765, -32765 },
		  finet[] = {	0, 0,		23,	   999, 1234, 3333, 9999, 12345,
						 24999, 17889, 17890 };
	//	last two frames are 40usec apart

	//	write auxiliary file 
	DataSet *set = dataSetServer->open("0010_PPPPPPOOLL_M1S00100AUX.FIT",
									   DataSet::Create);
	Table *tab = set->addTable("AUXILIARY", NUM_OF(coarset));
	ColumnData *cdframe =
			tab->addColumn("FRAME", Dal::Int32, "frame counter", "")->data();
	int32 *frame = cdframe->int32Data();

	ColumnData *cdccdid =
			tab->addColumn("CCDID", Dal::Int8, "CCD identifier", "")->data(),
			   *cdnodeid = tab->addColumn("CCDNODE", Dal::Int8,
										  "Node identifier", "")->data();
	int8  *ccdid = cdccdid->int8Data(),
		  *nodeid = cdnodeid->int8Data();

	ColumnData *cdftcoarse = tab->addColumn("FTCOARSE", Dal::Int16,
											"Coarse Frame Time", "s")->data(),
			   *cdftfine = tab->addColumn("FTFINE", Dal::Int16,
										  "Fine Frame Time", "40usec")->data();
	int16 *ftcoarse = 	cdftcoarse->int16Data(),
		  *ftfine = cdftfine->int16Data();

	for (unsigned n=0; n<NUM_OF(coarset); ++n) {
		frame[n] = n;
		ccdid[n] = 1;
		nodeid[n] = 0;
		ftcoarse[n] = coarset[n];
		ftfine[n] = finet[n];
	}

	delete cdframe;
	delete cdccdid;
	delete cdnodeid;
	delete cdftcoarse;
	delete cdftfine;
	dataSetServer->close(set);


	//
	//	write periodic HK file
	//
	set = dataSetServer->open("0010_PPPPPPOOLL_M1S00100PEH.FIT",
							   DataSet::Create);
	tab = set->addTable("PERIODIC_HK", 10);

    vector<unsigned long> size; size.push_back(19);
    ColumnData *tcol = tab->addColumn("TIME", Dal::DString,
                                     "time tag", "ERT", size)->data(),
			   *cdcoarseobt = tab->addColumn("E1573", Dal::Int32,
											 "COBT coarse", "sec")->data(),
			   *cdfineobt = tab->addColumn("EU573", Dal::Uint16,
										   "COBT fine", "1/65536s")->data();

	int32 *coarseobt = cdcoarseobt->int32Data();
	uint16 *fineobt = cdfineobt->uint16Data();

	for (unsigned n=0; n<10; ++n) {
		STime t = start + 10 * n;
		stringColumnRowSet(tcol, n, t.toString());
		coarseobt[n] = 1<<31;
		fineobt[n] = 21845;
	}

	delete tcol;
	delete cdcoarseobt;
	delete cdfineobt;
	dataSetServer->close(set);
}
